Al の進化に伴う課題と現状の取組

第1節

|図表 I\-4\-1\-1<br>生成AIの課題||||
|-|-|-|-|
|リスク|||事例|
|従来型AI<br>から存在<br>するリスク|バイアスのある結果及び差別的な結果の出力||●IT企業が自社で開発したAI人材採用システムが女性を差別するという機械学習面の欠陥を持<br>ち合わせていた|
||フィルターバブル及びエコーチェンバー現象||●SNS等によるレコメンドを通じた社会の分断が生じている|
||多様性の喪失||●社会全体が同じモデルを、同じ温度感で使った場合、導かれる意見及び回答がLLMによって<br>収束してしまい、多様性が失われる可能性がある|
||不適切な個人情報の取扱い||●透明性を欠く個人情報の利用及び個人情報の政治利用も問題視されている|
||生命、身体、財産の侵害||●Alが不適切な判断を下すことで、自動運転車が事故を引き起こし、生命や財産に深刻な損害<br>を与える可能性がある<br>●トリアージにおいては、Alが順位を決定する際に倫理的なバイアスを持つことで、公平性の<br>喪失等が生じる可能性がある|
||データ汚染攻撃||●AIの学習実施時及びサービス運用時には学習データへの不正データ混入、サービス運用時で<br>はアプリケーション自体を狙ったサイバー攻撃等のリスクが存在する|
||ブラックボックス化、判断に関する説明の要求||● AIの判断のブラックボックス化に起因する問題も生じている<br>●AIの判断に関する透明性を求める動きも上がっている|
||エネルギー使用量及び環境の負荷||●AIの利用拡大により、計算リソースの需要も拡大しており、結果として、データセンターが<br>増大しエネルギー使用量の増加が懸念されている|
|生成AIで<br>特に顕在化<br>したリスク|悪用||● Alの詐欺目的での利用も問題視されている|
||機密情報の流出||●AIの利用においては、個人情報や機密情報がプロンプトとして入力され、そのAIからの出力<br>等を通じて流出してしまうリスクがある|
||ハルシネーション||●生成Alが事実と異なることをもっともらしく回答する「ハルシネーション」に関してはAI開<br>発者·提供者への訴訟も起きている|
||偽情報、誤情報を鵜呑みにすること||●生成AIが生み出す誤情報を鵜呑みにすることがリスクとなりうる<br>●ディープフェイクは、各国で悪用例が相次いでいる|
||著作権との関係||●知的財産権の取扱いへの議論が提起されている|
||資格等との関係||●生成AIの活用を通じた業法免許や資格等の侵害リスクも考えうる|
||バイアスの再生成||●生成AIは既存の情報に基づいて回答を作るため既存の情報に含まれる偏見を増幅し、不公平<br>や差別的な出力が継続/拡大する可能性がある|

# 1 主要なLLMの概要

\(出典\)「AI事業者ガイドライン\(第1\.0版\)」別添\(概要\)

生成AIの基盤となる大規模言語モデル\(LLM\) の開発では、マイクロソフトやグーグルなど米<br>国ビックテック企業などが先行している状況にある。

しかし、日本以外の企業·研究機関がクローズに研究開発を進めたLLM を活用するだけでは、<br>LLM構築の過程がブラックボックス化してしまい、LLMを活用する際の権利侵害や情報漏えいな<br>どの懸念を払拭できない。日本語に強いLLMの利活用のためには、構築の過程や用いるデータが<br>明らかな、透明性の高い安心して利活用できる国産のLLM構築が必要となる\*3。すでに日本の企業<br>においても、独自にLLM開発に取り組んでおり、ここではその動向を紹介する。

ビッグテック企業が開発したLLMと比べると、日本では、中規模モデルのLLMが開発されてい<br>る傾向が見られる\(図表1\-4\-1\-2\)。

\*3 産業技術総合研究所プレスリリース「産総研の計算資源ABCIを用いて世界トップレベルの生成AIの開発を開始一産総研·東京工業大学·<br>LLM\-jp \(国立情報学研究所主宰\)が協力ー」\(2023年10月17日\),<https://www\.aist\.go\.jp/aist\_j/news/pr20231017\.html> \(2024/3/<br>参照\)

令和6年版 情報通信白書 第1部 47

デジタルテクノロジーの課題と現状の対応策<br>第4章
